@@ -13,6 +13,8 @@ class SSLSocketController(MainSocketController):
         context.load_verify_locations(cafile=self.MainSocket.CA)
         context.options |= ssl.OP_NO_SSLv3
         context.options |= ssl.OP_NO_SSLv2
+        context.options |= ssl.OP_NO_TLSv1
+        context.options |= ssl.OP_NO_TLSv1_1
         context.verify_mode = ssl.CERT_REQUIRED
         context.load_cert_chain(certfile=self.MainSocket.pemDir, keyfile=self.MainSocket.keyDir,
                                 password=self.MainSocket.password, )
@@ -21,16 +23,4 @@ class SSLSocketController(MainSocketController):
                                         self.MainSocket.sockProto)
         self.MainSocket.sock.bind((self.MainSocket.ip, self.MainSocket.port))
         self.MainSocket.sock = context.wrap_socket(self.MainSocket.sock, server_side=True)
-        return self.MainSocket.sock
-
-    def createClientSocket(self, serverIP):
-        context = ssl.SSLContext()
-        context.load_verify_locations(cafile=self.MainSocket.CA)
-        context.load_cert_chain(certfile=self.MainSocket.pemDir, keyfile=self.MainSocket.keyDir,
-                                password=self.MainSocket.password, )
-        context.verify_mode = ssl.CERT_OPTIONAL
-        context.check_hostname = False
-        context.set_ciphers('DEFAULT@SECLEVEL=1')
-        self.MainSocket.sock = socket.socket(self.MainSocket.socketAF, self.MainSocket.socketSTREAM)
-        self.MainSocket.sock = context.wrap_socket(self.MainSocket.sock)
         return self.MainSocket.sock
\ No newline at end of file
