@@ -5,7 +5,7 @@ class Filename:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         filename = Filename()
 
         filename.setINTAG(INTAG)
