@@ -5,7 +5,7 @@ class Submitter:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         submitter = Submitter()
 
         submitter.setINTAG(INTAG)
