@@ -5,7 +5,7 @@ class Tool:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         tool = Tool()
 
         tool.setINTAG(INTAG)
